@@ -3,7 +3,7 @@ package WWW::Google::Time;
 use warnings;
 use strict;
 
-our $VERSION = '1.001002'; # VERSION
+our $VERSION = '1.001003'; # VERSION
 
 use LWP::UserAgent;
 use URI;
@@ -54,8 +54,8 @@ sub get_time {
     my %data;
     # print $response->content;
     @data{ qw/time day_of_week month month_day year time_zone where/ } = $response->content
-    =~ m{<div class="_rkc _Peb">(.+?)</div><div class="_HOb _Qeb"> (\w+), <span style="white-space:nowrap">(\w+) (\d+), (\d+)</span> \((.+?)\) </div><span class="_HOb _Qeb">   Time in (.+?) </span></div></div>}
-#         <div class="_rkc _Peb">8:47 AM</div><div class="_HOb _Qeb"> Saturday, <span style="white-space:nowrap">August 30, 2014</span> (EDT) </div><span class="_HOb _Qeb">   Time in Toronto, ON, Canada </span></div></div>
+    =~ m{<div class="_rkc _Peb">(.+?)</div><div class="_HOb _Qeb"> (\w+), <span style="white-space:nowrap">(\w+) (\d+), (\d+)</span> \((.+?)\) </div><span class="_HOb _Qeb">\s+Time in (.+?) </span></div></div>}
+         # <div class="_rkc _Peb">12:23 PM</div><div class="_HOb _Qeb"> Wednesday, <span style="white-space:nowrap">December 31, 2014</span> (EST) </div><span class="_HOb _Qeb">  Time in Toronto, ON </span></div></div>
     or do {
         return $self->_set_error("Could not find time data for that location");
     };
@@ -244,16 +244,16 @@ Would be nice to be able to return all three results in an arrayref or something
 
 =head1 REPOSITORY
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-github.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+=for pod_spiffy start github section
 
 Fork this module on GitHub:
 L<https://github.com/zoffixznet/WWW-Google-Time>
 
-=for html  </div></div>
+=for pod_spiffy end github section
 
 =head1 BUGS
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-bugs.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+=for pod_spiffy start bugs section
 
 To report bugs or request features, please use
 L<https://github.com/zoffixznet/WWW-Google-Time/issues>
@@ -261,25 +261,25 @@ L<https://github.com/zoffixznet/WWW-Google-Time/issues>
 If you can't access GitHub, you can email your request
 to C<bug-WWW-Google-Time at rt.cpan.org>
 
-=for html  </div></div>
+=for pod_spiffy end bugs section
 
 =head1 AUTHOR
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-author.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+=for pod_spiffy start author section
 
-=for html   <span style="display: inline-block; text-align: center;"> <a href="http://metacpan.org/author/ZOFFIX"> <img src="http://www.gravatar.com/avatar/328e658ab6b08dfb5c106266a4a5d065?d=http%3A%2F%2Fwww.gravatar.com%2Favatar%2F627d83ef9879f31bdabf448e666a32d5" alt="ZOFFIX" style="display: block; margin: 0 3px 5px 0!important; border: 1px solid #666; border-radius: 3px; "> <span style="color: #333; font-weight: bold;">ZOFFIX</span> </a> </span>
+=for pod_spiffy author ZOFFIX
 
 =for text Zoffix Znet <zoffix at cpan.org>
 
-=for html  </div></div>
+=for pod_spiffy end author section
 
 =head1 CONTRIBUTORS
 
-=for html  <div style="display: table; height: 91px; background: url(http://zoffix.com/CPAN/Dist-Zilla-Plugin-Pod-Spiffy/icons/section-contributors.png) no-repeat left; padding-left: 120px;" ><div style="display: table-cell; vertical-align: middle;">
+=for pod_spiffy start contributors section
 
 Patches by Neil Stott and Zach Hauri (L<http://zach.livejournal.com/>)
 
-=for html  </div></div>
+=for pod_spiffy end contributors section
 
 =head1 LICENSE
 
